@@ -83,7 +83,7 @@ OPERATORS_FUNCTIONS = {
 }
 
 SET_OPERATORS = {"<", ">", "<=", ">=", "and", "&", "or", "|", "-", "^"}
-SET_OPERATORS_THAT_RETURN_SET = {"and", "&", "or", "|", "-", "^"}
+OPERATORS_THAT_RETURN_SET = {"and", "&", "or", "|", "-", "^"}
 
 # map from jmespath exceptions class names to readable error types
 JMESPATH_READABLE_ERRORS = {
@@ -239,27 +239,44 @@ class JMESPathProjectConfigFunctions(JMESPathFunctions):
     @jmespath_func_signature(
         {"types": []},
         {"types": ["string"]},
-        {"types": []},
+        {"types": [], "variadic": True},
     )
-    def _func_op(self, a: float, operator: str, b: float) -> t.Any:
-        try:
-            func = OPERATORS_FUNCTIONS[operator]
-        except KeyError:
-            raise OriginalJMESPathError(
-                f"Invalid operator '{operator}' passed to op() function,"
-                f" expected one of: {', '.join(list(OPERATORS_FUNCTIONS))}",
-            )
-        if (
-            isinstance(b, list)
-            and isinstance(a, list)
-            and operator in SET_OPERATORS
-        ):
-            # both values are lists and the operator is only valid for sets,
-            # so convert both values to set applying the operator
-            b, a = set(b), set(a)
-            if operator in SET_OPERATORS_THAT_RETURN_SET:
-                return list(func(a, b))
-        return func(a, b)
+    def _func_op(
+        self, a: float, operator: str, b: float, *args: t.Any
+    ) -> t.Any:
+        operators = []
+        current_op = None
+        for i, op_or_value in enumerate([operator, b] + (list(args) or [])):
+            if i % 2 == 0:
+                try:
+                    func = OPERATORS_FUNCTIONS[op_or_value]  # type: ignore
+                except KeyError:
+                    raise OriginalJMESPathError(
+                        f"Invalid operator '{op_or_value}' passed to op()"
+                        f" function at index {i}, expected one of:"
+                        f" {', '.join(list(OPERATORS_FUNCTIONS))}",
+                    )
+                else:
+                    current_op = (func, op_or_value)
+            else:
+                operators.append((current_op, op_or_value))
+
+        partial_result = a
+        for (func, operator), b_ in operators:  # type: ignore
+            if (
+                isinstance(b_, list)
+                and isinstance(partial_result, list)
+                and operator in SET_OPERATORS
+            ):
+                # both values are lists and the operator is only valid for sets,
+                # so convert both values to set applying the operator
+                if operator in OPERATORS_THAT_RETURN_SET:
+                    partial_result = list(func(set(partial_result), set(b_)))
+                else:
+                    partial_result = func(set(partial_result), set(b_))
+            else:
+                partial_result = func(partial_result, b_)
+        return partial_result
 
     @jmespath_func_signature({"types": ["array-string"]})
     def _func_shlex_join(self, cmd_list: t.List[str]) -> str:
@@ -464,6 +481,25 @@ class JMESPathProjectConfigFunctions(JMESPathFunctions):
     def _func_os(self) -> str:
         return sys.platform
 
+    @jmespath_func_signature({"types": ["string"]})
+    def _func_getenv(self, envvar: str) -> t.Optional[str]:
+        return os.environ.get(envvar)
+
+    @jmespath_func_signature(
+        {"types": ["string"]},
+        {"types": ["string", "null"]},
+    )
+    def _func_setenv(
+        self,
+        envvar: str,
+        value: t.Optional[str],
+    ) -> t.Dict[str, str]:
+        if value is None:
+            del os.environ[envvar]
+        else:
+            os.environ[envvar] = value
+        return dict(os.environ)
+
     # Github functions
     @jmespath_func_signature(
         {"types": ["string"]},
@@ -830,15 +866,21 @@ def smart_fixer_by_expected_value(
         key = ast["value"]
         return f"set(@, '{key}' `{json.dumps(expected_value)}`)"
     elif ast["type"] == "subexpression":
-        temporal_object = {}
+        try:
+            temporal_object = {}
 
-        _obj = {}
-        for i, child in enumerate(reversed(ast["children"])):
-            if i == 0:
-                _obj = {child["value"]: expected_value}
-            else:
-                _obj = {child["value"]: _obj}
-        temporal_object = _obj
+            _obj = {}
+            for i, child in enumerate(reversed(ast["children"])):
+                if child["type"] == "index_expression":
+                    return ""
+                if i == 0:
+                    _obj = {child["value"]: expected_value}
+                else:
+                    _obj = {child["value"]: _obj}
+        except KeyError:
+            return ""
+        else:
+            temporal_object = _obj
     elif ast["type"] == "function_expression" and ast["value"] == "type":
         if expected_value not in REVERSE_JMESPATH_TYPE_PYOBJECT:
             return ""
